@@ -60,7 +60,7 @@ fi
 
 # set defaults, if nothing given
 [ "${KERNEL}" = "" ] && KERNEL=$(uname -r)
-[ "${RELEASENAME}" = "" ] && RELEASENAME="Schmuie"
+[ "${RELEASENAME}" = "" ] && RELEASENAME="Schmollie"
 [ "${IMAGENAME}" = "" ] && IMAGENAME="Archlinux-allinone-$(date +%Y.%m)"
 
 # generate temp directories
@@ -73,6 +73,7 @@ ALLINONE=$(mktemp -d /tmp/allinone.XXX)
 # create directories
 mkdir ${ALLINONE}/arch
 mkdir ${ALLINONE}/isolinux
+mkdir ${ALLINONE}/clamav
 
 # extract tarballs
 tar xvf lowmem-i686.tar -C ${LOWMEM} || exit 1
@@ -83,10 +84,18 @@ tar xvf core-x86_64.tar -C ${CORE64} || exit 1
 # move in packages
 mv ${LOWMEM}/tmp/*/core-i686 ${ALLINONE}/
 mv ${LOWMEM64}/tmp/*/core-x86_64 ${ALLINONE}/
+mv ${LOWMEM}/tmp/*/core-any ${ALLINONE}/
 
 # move in doc
 mv ${CORE}/tmp/*/arch/archdoc.txt ${ALLINONE}/arch/
 
+# copy in clamav db files
+if [ -d /var/lib/clamav ]; then
+    cp /var/lib/clamav/daily.cvd ${ALLINONE}/clamav/
+    cp /var/lib/clamav/main.cvd ${ALLINONE}/clamav/
+    cp /var/lib/clamav/mirrors.dat ${ALLINONE}/clamav/
+fi
+
 # place kernels and memtest
 mv ${LOWMEM}/tmp/*/isolinux/vmlinuz ${ALLINONE}/isolinux/
 mv ${LOWMEM64}/tmp/*/isolinux/vmlinuz ${ALLINONE}/isolinux/vm64
